# -*- coding: utf-8 -*-
"""
Fonction d'aide à la manipulation d'image
"""

from scipy import misc
import matplotlib.pyplot as plt


def lit_image(chemin):
    image = misc.imread(chemin)
    _, _, col_nb = image.shape
    if col_nb > 3:
        return image[:, :, 0:3]
    return image


def affiche_image(img):
    plt.imshow(img, interpolation='nearest')
    plt.axis('off')
    plt.show()


def noir_et_blanc(img):
    """
    Retourne l'image img transformée en noir et blanc
    """
    img2 = img.copy()  # copie pour eviter de modifier l'image de départ
    for i in range(len(img2)):
        for j in range(len(img2[0])):
            s = sum(img2[i][j]) / 3
            img2[i][j] = [s, s, s]
    return img2


def noir_et_blanc2(img):
    """
    Même chose, en utilisant des coefficients pour calculer la moyenne : 0.299R + 0.587G + 0.114B
    """
    img2 = img.copy()  # copie pour eviter de modifier l'image de départ
    for i in range(len(img2)):
        for j in range(len(img2[0])):
            r, g, b = img2[i][j]
            s = 0.299*r + 0.587*g + 0.114*b
            img2[i][j] = [s, s, s]
    return img2


def elimine_couleur(img, couleur):
    if couleur == 'R':
        c = 0
    elif couleur == 'G':
        c = 1
    else:
        c = 2
    for i in range(len(img)):
        for j in range(len(img[0])):
            img[i][j][c] = 0
    return img


def floyd_couleur(img, seuil, i_couleur):
    """
    Applique la transformation décrite dans l'énoncé à l'image donnée, sur la couleur d'indice
    i_couleur. Aucun besoin de copier l'image ici
    """
    H = len(img)
    L = len(img[0])
    for i in range(H):
        for j in range(L):
            if img[i][j][i_couleur] < seuil:
                e = img[i][j][i_couleur]
                img[i][j][i_couleur] = 0
            else:
                e = img[i][j][i_couleur] - 255
                img[i][j][i_couleur] = 255
            if i < L - 1:  # pas la dernière ligne
                if j > 0:
                    img[i + 1][j - 1][i_couleur] += 3*e/16
                if j < L - 1:
                    img[i][j + 1][i_couleur] += 5*e/16
                    img[i + 1][j + 1][i_couleur] += e/16
                img[i + 1][j][i_couleur] += 5*e/16
            elif j < L - 1:
                img[i][j + 1][i_couleur] += 5*e/16
    return img


def floyd(img, seuil):
    """
    Retourne l'image obtenue par transformation de Floyd depuis img.
    Ne modifie pas l'image source.
    """
    img2 = img.copy()
    for i in range(3):
        floyd_couleur(img2, seuil, i)
    return img2


def photomaton(img):
    """
    A vous de jouer !
    """
    img2 = img.copy()
    H = len(img)
    L = len(img[0])
    if H != 512 or L != 512:
        print("Mauvaise taille d'image")
        return
    for i in range(H):
        for j in range(L):
            ni = i//2 + (i % 2)*256
            nj = j // 2 + (j % 2)*256
            img2[ni][nj] = img[i][j]
    return img2


def photomaton_gen(img):
    img2 = img.copy()
    H = len(img)
    L = len(img[0])
    if H % 2 or L % 2:
        print("mauvaise taille")
    moitieH = H // 2
    moititeL= L // 2
    for i in range(H):
        for j in range(L):
            ni = i//2 + (i % 2)*moitieH
            nj = j // 2 + (j % 2)*moitieL
            img2[ni][nj] = img[i][j]
    return img2
